@@ -10,6 +10,7 @@ BEGIN TRANSACTION;
 --
 CREATE TABLE Foo (
   foo INTEGER PRIMARY KEY NOT NULL,
-  bar VARCHAR(10) NOT NULL
+  bar VARCHAR(10) NOT NULL,
+  baz VARCHAR(10)
 );
 COMMIT
\ No newline at end of file
